#[non_exhaustive]pub enum Tlv8Error {
UnexpectedEof,
IntegerTooLarge {
requested: usize,
actual: usize,
},
}Expand description
All errors hap-tlv8 can produce.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedEof
The reader reached the end of the input before a declared value’s bytes were available (a truncated item).
IntegerTooLarge
A typed getter was asked for an integer width that does not match the
number of bytes stored for that type (for example get_u16 on a
3-byte value).